"""
Program for converting the official namesday list from the Latvian
language center into a JSON file. The list is in the form of an Excel
file, which is converted to a JSON file.

Input data: 
https://data.gov.lv/dati/lv/dataset/latviesu-tradicionalais-un-paplasinatais-kalendarvardu-saraksts
"""

import pandas as pd
import csv
import json

BASIC_FILENAME = "tradic_vardadienu_saraksts.xlsx"
BASIC_CSV = "tradic_vardadienu_saraksts.csv"
BASIC_OUTPUT = "tradic_vardadienu_saraksts.json"

def convert_basic_list():

    basic_df = pd.read_excel(BASIC_FILENAME)
    basic_df.to_csv(BASIC_CSV, index=False, header=False)

    dataset = {}

    with open(BASIC_CSV) as inf:

        csv_in = csv.reader(inf)

        for rec in csv_in:

            if len(rec) != 2:
                break

            date_str, names_str = rec
            day, month = date_str.split(".")[:2]
            date = f"{month}-{day}"

            names_str = names_str.replace(".", ",")
            names = names_str.split(",")
            names = [text.strip() for text in names]

            dataset[date] = names

    with open(BASIC_OUTPUT, "w") as outf:

        json.dump(dataset, outf, indent=2)


def main():
    
    convert_basic_list()

if __name__ == "__main__":
    main()


#!/usr/bin/env python3

"""
A program for working with the Latvian name day calendar.

It can display today's name days and look up the name day date
for a specific name.
"""

import datetime as dt
import json
import importlib.resources
import click


NAMEDAY_LIST = "tradic_vardadienu_saraksts.json"

@click.group()
def cli():
    """
    A program for lookup in the Latvian name day calendar.

    It can display today's name days and look up the name day date
    for a specific name.
    """
    pass

def read_namedays():

    with importlib.resources.open_text('lv_namedays.data', NAMEDAY_LIST) as f:
    #with open(NAMEDAY_LIST, "r", encoding="utf-8") as f:
        namedays = json.load(f)

    return namedays

@cli.command()
def now():
    """
    Show today's name days.
    """
    print_namedays(dt.datetime.now().strftime("%m-%d"))

def print_namedays(date_str):
    
    namedays = read_namedays()

    click.echo()

    if date_str in namedays:
        nameday = namedays[date_str]
        click.echo(f"Šodienas vārda dienas: {", ".join(nameday)}")
    else:
        click.echo("Šodien nav neviena vārda diena.")

    click.echo()

def get_date_for_name(name):

    namedays = read_namedays()

    # Make search case insensitive
    namedays = {date: [n.lower() for n in names] for date, names in namedays.items()}

    # Search for the name in the calendar
    for date, names in namedays.items():
        if name.lower() in names:
            return date
    return None

@cli.command()
@click.argument("name")
def name(name):
    """
    Show the name day for a specific name.
    """
    print_nameday_for_name(name)


def print_nameday_for_name(name):
    
    date = get_date_for_name(name)

    click.echo()

    if date:
        click.echo(f"{name}: vārda diena ir {date} (MM-DD)")
    else:
        click.echo(f"Nevarēju atrast vārda dienu: {name}")

    click.echo()


def print_namedays_for_week():
    today = dt.datetime.now()
    start_date = today - dt.timedelta(days=3)
    end_date = today + dt.timedelta(days=3)

    namedays = read_namedays()

    click.echo()

    for i in range(7):
        current_date = start_date + dt.timedelta(days=i)
        date_str = current_date.strftime("%m-%d")

        if date_str in namedays:
            nameday = namedays[date_str]

            bold = False

            if current_date == today:
                bold = True

            click.secho(f"{date_str} vārda dienas: {", ".join(nameday)}", bold=bold)
        else:
            click.echo(f"{date_str} nav neviena vārda diena")

    click.echo()

@cli.command()
def week():
    """
    Show name days for the current day and 3 days before and after it.
    """
    print_namedays_for_week()

def main():

    cli()

    # TODO:
    #  - Create library functions for nameday lookup

if __name__ == "__main__":
    main()



"""
Program for converting the official extended namesday list from the 
Latvian language center into a JSON file. The list is in the form 
of an Excel file, which is converted to a JSON file.

Input data: 
https://data.gov.lv/dati/lv/dataset/latviesu-tradicionalais-un-paplasinatais-kalendarvardu-saraksts
"""

import pandas as pd
import csv
import json

EXTENDED_CSV = "paplasinatais_saraksts_.csv"
EXTENDED_OUTPUT = "paplasinatais_saraksts.json"

def convert_extended_list():

    dataset = {}

    with open(EXTENDED_CSV) as inf:

        csv_in = csv.reader(inf, delimiter=";")

        # Skip the header row
        next(csv_in)

        for rec in csv_in:

            if len(rec) != 2:
                break

            date_str, names_str = rec

            # Skip incorrect dates (if any)
            if len(date_str.split(".")) < 2:
                continue

            day, month = date_str.split(".")[:2]

            date = f"{month}-{day}"

            has_name_day = False

            if "Visu neparasto un kalendāros neierakstīto vārdu diena " in names_str:
                names_str = names_str.replace("Visu neparasto un kalendāros neierakstīto vārdu diena ", "")
                has_name_day = True

            names_str = names_str.replace(".", ",")
            names_str = names_str.replace(" ", ",")

            names = names_str.split(",")
            # Also removes "–" from the list
            names = [text.strip() for text in names if text != "–" and text != ""]

            if has_name_day:
                names.append("Visu neparasto un kalendāros neierakstīto vārdu diena")

            dataset[date] = names

    with open(EXTENDED_OUTPUT, "w") as outf:
        json.dump(dataset, outf, indent=2)


def main():
    
    convert_extended_list()

if __name__ == "__main__":
    main()